@@ -1,3 +1,5 @@
+# Copyright 2012 - 2013, Steve Rader
+# Copyright 2013 - 2014, Scott Kostyshak
 
 sub init_curses {
   my $m = $_[0];
@@ -6,11 +8,11 @@ sub init_curses {
   curs_set(0);
   start_color();
   use_default_colors();
-  init_pair($COLOR_ERRORS,231,1); # white on red # FIXME xterm specific, wrong for ANSI 
-  if ( $m eq 'init' ) { 
-    init_pair($COLOR_SELECTION,231,4); # white on blue  # FIXME xterm specific, wrong for ANSI
+  init_pair($COLOR_ERRORS,COLOR_WHITE,COLOR_RED);
+  if ( $m eq 'init' ) {
+    init_pair($COLOR_SELECTION,COLOR_WHITE,COLOR_BLUE);
   }
-  init_pair($COLOR_EMPTY_LINE,4,-1); # blue foreground
+  init_pair($COLOR_EMPTY_LINE,COLOR_BLUE,-1); # blue foreground
   my $HEADER_SIZE = 3;
   $REPORT_LINES = $LINES - $HEADER_SIZE - 1;
   $REPORT_COLS = $COLS - 2;
@@ -18,6 +20,7 @@ sub init_curses {
   $report_win = newwin($REPORT_LINES+$HEADER_SIZE, $REPORT_COLS+2, 3, 1);
   $prompt_win = newwin(1, $COLS, $LINES-1, 0);
   keypad($report_win, 1);
+  keypad($prompt_win, 1);
 }
 
 #------------------------------------------------------------------
